#[repr(C)]pub struct IterSizeHint {
pub lower: usize,
pub upper: usize,
pub has_upper: bool,
}Expand description
Return the lower and upper bounds of the iterator, if known.
Safety
The iter parameter must point to aligned, initialized memory of the correct type.
Fields
lower: usizeLower bound on remaining items.
upper: usizeUpper bound on remaining items when has_upper is true.
has_upper: boolWhether upper contains a real upper bound.