pub trait IterItem {
type Item;
}Expand description
A kind of item that an IterVTable returns
This trait is needed as a utility, so the functions within IterVTable
can apply the appropriate type to their result types.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".